package org.jtheque.primary.dao.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.JThequeDao;
import org.jtheque.primary.od.CollectionImpl;

import java.util.List;

/**
 * A DAO for collections specification.
 *
 * @author Baptiste Wicht
 */
public interface IDaoCollections extends JThequeDao {
    String TABLE = "T_COLLECTIONS";

    /**
     * Return the collections.
     *
     * @return All the collections.
     */
    List<CollectionImpl> getCollections();

    /**
     * Return the collection with the specific ID.
     *
     * @param id The searched ID.
     * @return The corresponding collection.
     */
    CollectionImpl getCollection(int id);

    CollectionImpl getCollection(String name);

    /**
     * Create a new collection.
     *
     * @param collection The collection to create.
     */
    void create(CollectionImpl collection);

    /**
     * Return the current collection.
     *
     * @return The current collection.
     */
    CollectionImpl getCurrentCollection();

    /**
     * Set the current collection.
     *
     * @param collection The current collection to set.
     */
    void setCurrentCollection(CollectionImpl collection);
}