package org.jtheque.primary.od;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.primary.od.abstraction.Lending;

/**
 * A lending.
 *
 * @author Baptiste Wicht
 */
public final class LendingImpl extends Lending {
    private final LendingTemporaryContext temporaryContext;

    /**
     * Construct a new FilmImpl.
     */
    public LendingImpl() {
        super();

        temporaryContext = new LendingTemporaryContext();
    }

    @Override
    public LendingTemporaryContext getTemporaryContext() {
        return temporaryContext;
    }
    
    @Override
    public String getAffichableText() {
        return "Emprunt de :  " + getTheOther();
    }

    @Override
    public int hashCode() {
        int hashCode = 17;

        hashCode = HASHCODEPRIME * hashCode + getId();
        hashCode = HASHCODEPRIME * hashCode + (getDate() == null ? 0 : getDate().hashCode());
        hashCode = HASHCODEPRIME * hashCode + (getTheBorrower() == null ? 0 : getTheBorrower().hashCode());
        hashCode = HASHCODEPRIME * hashCode + (getPrimaryImpl() == null ? 0 : getPrimaryImpl().hashCode());
        hashCode = HASHCODEPRIME * hashCode + getTheOther();

        return hashCode;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }

        if (obj == null) {
            return false;
        }

        if (getClass() != obj.getClass()) {
            return false;
        }

        final Lending other = (Lending) obj;

        if (getId() != other.getId()) {
            return false;
        }

        if (getDate() == null) {
            if (other.getDate() != null) {
                return false;
            }
        } else if (!getDate().equals(other.getDate())) {
            return false;
        }

        if (getTheOther() != other.getTheOther()) {
            return false;
        }

        if (getPrimaryImpl() == null) {
            if (other.getPrimaryImpl() != null) {
                return false;
            }
        } else if (!getPrimaryImpl().equals(other.getPrimaryImpl())) {
            return false;
        }

        if (getTheBorrower() == null) {
            if (other.getTheBorrower() != null) {
                return false;
            }
        } else if (!getTheBorrower().equals(other.getTheBorrower())) {
            return false;
        }

        return false;
    }
}