package org.jtheque.primary.services.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.primary.od.TypeImpl;
import org.jtheque.core.managers.persistence.able.DataContainer;

import java.util.List;

import com.sun.corba.se.impl.orbutil.RepositoryIdCache_1_3_1;

/**
 * A service for the types functions.
 *
 * @author Baptiste Wicht
 */
public interface ITypesService extends DataContainer<TypeImpl> {
    String DATA_TYPE = "Types";

    /**
     * Return the default type.
     *
     * @return The default type
     */
    TypeImpl getDefaultType();

    /**
     * Return all the types.
     *
     * @return A List containing all the types.
     */
    List<TypeImpl> getTypes();

    /**
     * Create the type.
     *
     * @param type The type to create.
     */
    void create(TypeImpl type);

    /**
     * Delete the type.
     *
     * @param type The type to delete.
     * @return true if the type has been deleted.
     */
    boolean delete(TypeImpl type);

    /**
     * Save the type.
     *
     * @param type The type to save.
     */
    void save(TypeImpl type);

    boolean exists(TypeImpl type);

    TypeImpl getType(String name);

    boolean hasNoTypes();

    void createAll(Iterable<TypeImpl> types);
}