package org.jtheque.primary.services.impl;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.DataListener;
import org.jtheque.primary.dao.able.IDaoBorrowers;
import org.jtheque.primary.od.BorrowerImpl;
import org.jtheque.primary.services.able.IBorrowersService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * A borrowers service implementation.
 *
 * @author Baptiste Wicht
 */
@Service
public final class BorrowersService implements IBorrowersService {
    @Resource
    private IDaoBorrowers daoBorrowers;

    @Override
    @Transactional
    public boolean delete(BorrowerImpl borrower) {
        return daoBorrowers.delete(borrower);
    }

    @Override
    @Transactional
    public void create(BorrowerImpl borrower) {
        if(borrower == null){
            borrower = getEmptyBorrower();
        }
        
        daoBorrowers.create(borrower);
    }

    @Override
    public List<BorrowerImpl> getBorrowers() {
        return daoBorrowers.getBorrowers();
    }

    @Override
    @Transactional
    public void save(BorrowerImpl borrower) {
        daoBorrowers.save(borrower);
    }

    @Override
    public boolean hasNoBorrowers() {
        return getBorrowers().isEmpty();
    }

    @Override
    public List<BorrowerImpl> getDatas() {
        return getBorrowers();
    }

    @Override
    public void addDataListener(DataListener listener) {
        daoBorrowers.addDataListener(listener);
    }

    @Override
    @Transactional
    public void clearAll() {
        daoBorrowers.clearAll();
    }

    @Override
    public String getDataType() {
        return DATA_TYPE;
    }

    private BorrowerImpl getEmptyBorrower() {
        return new BorrowerImpl();
    }
}