package org.jtheque.primary.view.impl.frames;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.primary.od.KindImpl;
import org.jtheque.primary.view.able.IKindView;
import org.jtheque.primary.view.impl.models.KindModel;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.utils.ui.ValidationUtils;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.core.managers.view.impl.components.InfiniteWaitFigure;
import org.jtheque.core.managers.view.impl.frame.abstraction.SwingDialogView;
import org.jtheque.utils.ui.SwingUtils;
import org.jtheque.utils.ui.GridBagUtils;
import org.jtheque.primary.od.abstraction.Data;

import javax.swing.JFrame;
import javax.swing.JTextField;
import javax.annotation.PostConstruct;
import java.awt.Container;
import java.awt.Frame;
import java.util.List;

/**
 * The view for kind.
 *
 * @author Baptiste Wicht
 */
public final class KindView extends SwingDialogView implements IKindView {
    private static final long serialVersionUID = -3525319522701158262L;

    private JTextField fieldName;

    private JThequeAction validateAction;
    private JThequeAction closeAction;
    
    /**
     * Construct a new JFrameKind modal to his parent view.
     * 
     * @param frame The parent frame. 
     */
    public KindView(Frame frame) {
        super(frame);
    }

    @Override
    public void reload() {
        setTitleKey("kind.view.title");

        getModel().setKind(null);

        fieldName.setText("");
    }


    @Override
    public void reload(Data data) {
        KindImpl kind = (KindImpl) data;

        getModel().setKind(kind);

        setTitle(Managers.getManager(ILanguageManager.class).getMessage("kind.view.title.modify") +
                kind.getAffichableText());

        fieldName.setText(kind.getName());
    }

    @Override
    @PostConstruct
    public void build() {
        setContentPane(buildContentPane());
        setResizable(true);
        setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
        setIconImage(getDefaultWindowIcon());
        setWaitFigure(new InfiniteWaitFigure());
        pack();

        reload();
        
        SwingUtils.centerFrame(this);
    }

    /**
     * Build the content pane.
     *
     * @return The builded content pane.
     */
    private Container buildContentPane() {
        PanelBuilder builder = new PanelBuilder();
        
        builder.addI18nLabel("kind.view.name", builder.gbcSet(0, 0));

        fieldName = builder.add(new JTextField(15), builder.gbcSet(1, 0, GridBagUtils.HORIZONTAL));
        SwingUtils.addFieldLenghtLimit(fieldName, 50);
        SwingUtils.addFieldValidateAction(fieldName, validateAction);
        
        builder.addButtonBar(builder.gbcSet(0, 1, GridBagUtils.HORIZONTAL), validateAction, closeAction);
        
        return builder.getPanel();
    }

    @Override
    public JTextField getFieldName() {
        return fieldName;
    }

    @Override
    public KindModel getModel() {
        return (KindModel) super.getModel();
    }

    @Override
    public void refreshText() {
        super.refreshText();

        if (getModel().getKind() != null) {
            setTitle(Managers.getManager(ILanguageManager.class).getMessage("kind.view.title.modify") +
                    getModel().getKind().getAffichableText());
        }
    }

    @Override
    protected void validate(List<JThequeError> errors) {
        ValidationUtils.rejectIfEmpty(fieldName.getText(), "kind.view.name", errors);
        ValidationUtils.rejectIfLongerThan(fieldName.getText(), "kind.view.name", 150, errors);
    }

    public void setValidateAction(JThequeAction validateAction) {
        this.validateAction = validateAction;
    }

    public void setCloseAction(JThequeAction closeAction) {
        this.closeAction = closeAction;
    }
}