package org.jtheque.primary.view.impl.frames;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.primary.od.TypeImpl;
import org.jtheque.primary.view.able.ITypeView;
import org.jtheque.primary.view.impl.models.TypeModel;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.utils.ui.ValidationUtils;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.core.managers.view.impl.components.InfiniteWaitFigure;
import org.jtheque.core.managers.view.impl.frame.abstraction.SwingDialogView;
import org.jtheque.utils.ui.SwingUtils;
import org.jtheque.utils.ui.GridBagUtils;
import org.jtheque.primary.od.abstraction.Data;

import javax.swing.JFrame;
import javax.swing.JTextField;
import javax.annotation.PostConstruct;

import java.awt.Container;
import java.awt.Frame;
import java.util.List;

/**
 * The view for type.
 *
 * @author Baptiste Wicht
 */
public final class TypeView extends SwingDialogView implements ITypeView {
    private static final long serialVersionUID = -3525319522701158262L;

    private JTextField fieldName;

    private JThequeAction validateAction;
    private JThequeAction closeAction;

    /**
     * Construct a new JFrameType modal to his parent view.
     * 
     * @param frame The parent frame. 
     */
    public TypeView(Frame frame) {
        super(frame);
    }

    @Override
    public void reload() {
        setTitleKey("type.view.title");

        fieldName.setText("");

        getModel().setType(null);
    }

    @Override
    public void reload(Data newType) {
        TypeImpl type = (TypeImpl) newType;

        setTitle(Managers.getManager(ILanguageManager.class).getMessage("type.view.title.modify") + type.getName());

        fieldName.setText(type.getName());

        getModel().setType(type);
    }

    @Override
    @PostConstruct
    public void build() {
        setContentPane(buildContentPane());
        setResizable(true);
        setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
        setIconImage(getDefaultWindowIcon());
        setWaitFigure(new InfiniteWaitFigure());
        pack();

        reload();
        
        SwingUtils.centerFrame(this);
    }

    /**
     * Build the content pane.
     *
     * @return The builded content pane.
     */
    private Container buildContentPane() {
        PanelBuilder builder = new PanelBuilder();
        
        builder.addI18nLabel("saga.view.name", builder.gbcSet(0, 0));

        fieldName = builder.add(new JTextField(15), builder.gbcSet(1, 0, GridBagUtils.HORIZONTAL));
        SwingUtils.addFieldLenghtLimit(fieldName, 50);
        SwingUtils.addFieldValidateAction(fieldName, validateAction);
        
        builder.addButtonBar(builder.gbcSet(0, 1, GridBagUtils.HORIZONTAL), validateAction, closeAction);
        
        return builder.getPanel();
    }

    @Override
    public JTextField getFieldName() {
        return fieldName;
    }

    @Override
    public void refreshText() {
        super.refreshText();

        if (getModel().getType() != null) {
            setTitle(Managers.getManager(ILanguageManager.class).getMessage("type.view.title.modify") +
                            getModel().getType().getName());
        }
    }

    @Override
    public TypeModel getModel() {
        return (TypeModel) super.getModel();
    }

    @Override
    protected void validate(List<JThequeError> errors) {
        ValidationUtils.rejectIfEmpty(fieldName.getText(), "type.view.name", errors);
        ValidationUtils.rejectIfLongerThan(fieldName.getText(), "type.view.name", 150, errors);
    }

    public void setValidateAction(JThequeAction validateAction) {
        this.validateAction = validateAction;
    }

    public void setCloseAction(JThequeAction closeAction) {
        this.closeAction = closeAction;
    }
}