package org.jtheque.primary.view.impl.listeners;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.primary.od.abstraction.Data;

import java.util.EventObject;

/**
 * Cette classe rprsente un vnement qui agit lors d'une modification sur un objet dans les fentres de
 * modification et d'ajout.
 *
 * @author Baptiste Wicht
 */
public final class ObjectChangedEvent extends EventObject {
    private static final long serialVersionUID = 4356006373361686392L;

    /* Variables */
    private final Data object;

    /**
     * Construcuteur qui construit un nouveal vnement avec la source et un objet changeant vide.
     *
     * @param source The source of the event
     */
    public ObjectChangedEvent(Object source) {
        this(source, null);
    }
    
    /**
     * Constructeur qui construit un nouvel vnement avec un la source, l'objet qui a chang et s'il faut changer
     * ou non le mode.
     *
     * @param source     The source of the event
     * @param object     The object who has changed
     */
    public ObjectChangedEvent(Object source, Data object) {
        super(source);

        this.object = object;
    }

    /**
     * Cette mthode permet de rcuprer l'objet ayant t modifi.
     *
     * @return L'objet  l'origine du changement
     */
    public Data getObject() {
        return object;
    }
}
