package org.jtheque.primary.view.impl.models;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.DataEvent;
import org.jtheque.core.managers.persistence.Entity;
import org.jtheque.core.managers.persistence.able.DataContainer;
import org.jtheque.core.managers.persistence.able.DataListener;
import org.jtheque.primary.od.abstraction.Data;

import javax.swing.DefaultComboBoxModel;
import java.util.List;

/**
 * A combobox model with the data in a cache.
 *
 * @author Baptiste Wicht
 * @param <T> The entity class on the model.
 */
public final class DataContainerCachedComboBoxModel<T extends Data> extends DefaultComboBoxModel implements DataListener {
    private static final long serialVersionUID = -5108796092884300590L;

    private final DataContainer<T> container;

    private List<T> datas;

    /**
     * Construct a new DataContainerCachedComboBoxModel with a specific container.
     *
     * @param container The data container.
     */
    public DataContainerCachedComboBoxModel(final DataContainer<T> container) {
        super();

        this.container = container;
        datas = container.getDatas();

        container.addDataListener(this);
    }

    @Override
    public Object getElementAt(final int index) {
        return getDatas().get(index);
    }

    @Override
    public int getSize() {
        return getDatas().size();
    }

    /**
     * Return the selected data in the model.
     *
     * @return The data who's selected.
     */
    @SuppressWarnings("unchecked")
    public T getSelectedData() {
        return (T) getSelectedItem();
    }

    @Override
    public void dataChanged(final DataEvent e) {
        datas = container.getDatas();

        fireContentsChanged(this, 0, getSize());
    }

    /**
     * Return the datas.
     *
     * @return The datas.
     */
    private List<? extends Entity> getDatas() {
        return datas;
    }

    /**
     * Select the first element. If there is no element, nothing will be done. 
     * 
     */
    public void selectFirst() {
        if(!datas.isEmpty()){
            setSelectedItem(datas.get(0));
        }
    }
}