package org.jtheque.primary.view.impl.models.tree;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.util.ArrayList;
import java.util.List;

/**
 * Represents a category of a tree model.
 *
 * @author Baptiste Wicht
 */
public final class Category {
    private final List<Element> elements;
    private final String name;

    /**
     * Constructs a new category.
     *
     * @param name The name of element
     */
    public Category(String name) {
        super();

        this.name = name;
        elements = new ArrayList<Element>(20);
    }

    /**
     * Add a new element to category.
     *
     * @param element The new element
     */
    public void addElement(Element element) {
        elements.add(element);
    }

    /**
     * Return the number of elements of the category.
     *
     * @return The sum of all the elements in the category
     */
    public int getElementsCount() {
        return elements.size();
    }

    /**
     * Return the element at the specified position.
     *
     * @param index The position
     * @return The element
     */
    public Element getElement(int index) {
        return elements.get(index);
    }

    /**
     * Return the index of an element.
     *
     * @param element The element we search
     * @return The index
     */
    public int getIndexOf(Element element) {
        return elements.indexOf(element);
    }

    /**
     * Return the name of the category.
     *
     * @return The name
     */
    public String getName() {
        return name;
    }

    @Override
    public String toString() {
        return name;
    }
}