package org.jtheque.primary.view.impl.renderers;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdesktop.swingx.JXImagePanel;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.resource.IResourceManager;
import org.jtheque.core.managers.resource.ImageType;
import org.jtheque.core.utils.db.DaoNotes.NoteType;
import org.jtheque.core.utils.db.Note;
import org.jtheque.primary.PrimaryUtils;

import javax.swing.JList;
import javax.swing.ListCellRenderer;
import java.awt.Component;
import java.awt.image.BufferedImage;

/**
 * Cette classe permet de changer l'apparence de la liste affichant les notes possibles avec des toiles.
 *
 * @author Baptiste Wicht
 */
public final class NoteComboRenderer extends JXImagePanel implements ListCellRenderer {
    private static final long serialVersionUID = 1L;

    private static final BufferedImage[] STATS;

    static {
        IResourceManager images = Managers.getManager(IResourceManager.class);

        STATS = new BufferedImage[7];

        for (int i = 1; i < 8; ++i) {
            STATS[i - 1] = images.getImage(PrimaryUtils.IMAGE_BASENAME, "Star" + i, ImageType.JPG);
        }
    }

    @Override
    public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected,
                                                  boolean cellHasFocus) {

        if (isSelected) {
            setBackground(list.getSelectionBackground());
            setForeground(list.getSelectionForeground());
        } else {
            setBackground(list.getBackground());
            setForeground(list.getForeground());
        }

        if (value != null) {
            Note note = (Note) value;

            if (note.getValue() == NoteType.ERROR) {
                setImage(STATS[NoteType.UNDEFINED.intValue() - 1]);
            } else {
                setImage(STATS[note.getValue().intValue() - 1]);
            }
        }

        return this;
    }
}